# Run all tests of the package
# 
# Author: Emilio L. Cano
###############################################################################


library(SixSigma)

testthat::test_package("SixSigma")
